@@ -71,7 +71,8 @@ g_synaptics_get_value_from_synclient (const gchar *key)
 			{
 				gchar *str = g_strndup (p1 + 1, p2 - p1);
 				gchar *str2 = g_strdup (g_strchug (str));
-				value = g_ascii_strtod (str2, NULL);
+
+				value = g_ascii_strtod (str2, NULL);	// converted extracted string to gdouble
 				g_free (str);
 				g_free (str2);
 			}
@@ -373,8 +374,8 @@ g_synaptics_is_edge_motion_enabled (GSynaptics *synaptics)
 	}
 }
 
-gdouble
-g_synaptics_accel_delta (GSynaptics *synaptics)
+gint
+g_synaptics_accel_factor (GSynaptics *synaptics)
 {
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
 	if (!g_synaptics_is_valid(synaptics))
@@ -382,16 +383,19 @@ g_synaptics_accel_delta (GSynaptics *synaptics)
 
 	if (priv->synclient)
 	{
-		return (gdouble)g_synaptics_get_value_from_synclient ("AccelFactor");
+		// Note (by Eugene Sia): returning gdouble instead of gint with value * 1000 
+		// seems to cause a change in value when the value is returned to the calling function.
+		// Possible bug in the gdouble implementation?
+		return (gint) (g_synaptics_get_value_from_synclient ("AccelFactor") * 1000);
 	}
 	else
 	{
-		return SYNSHM(synaptics)->accl;
+		return (gint) (SYNSHM(synaptics)->accl * 1000);
 	}
 }
 
-gdouble
-g_synaptics_min_speed_delta (GSynaptics *synaptics)
+gint
+g_synaptics_min_speed (GSynaptics *synaptics)
 {
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
 	if (!g_synaptics_is_valid(synaptics))
@@ -399,16 +403,16 @@ g_synaptics_min_speed_delta (GSynaptics *synaptics)
 
 	if (priv->synclient)
 	{
-		return (gdouble)g_synaptics_get_value_from_synclient ("MinSpeed");
+		return (gint) (g_synaptics_get_value_from_synclient ("MinSpeed") * 1000);
 	}
 	else
 	{
-		return SYNSHM(synaptics)->min_speed;
+		return (gint) (SYNSHM(synaptics)->min_speed * 1000);
 	}
 }
 
-gdouble
-g_synaptics_max_speed_delta (GSynaptics *synaptics)
+gint
+g_synaptics_max_speed (GSynaptics *synaptics)
 {
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
 	if (!g_synaptics_is_valid(synaptics))
@@ -416,11 +420,11 @@ g_synaptics_max_speed_delta (GSynaptics *synaptics)
 
 	if (priv->synclient)
 	{
-		return (gdouble)g_synaptics_get_value_from_synclient ("MaxSpeed");
+		return (gint) (g_synaptics_get_value_from_synclient ("MaxSpeed") * 1000);
 	}
 	else
 	{
-		return SYNSHM(synaptics)->max_speed;
+		return (gint) (SYNSHM(synaptics)->max_speed * 1000);
 	}
 }
 
@@ -700,7 +704,7 @@ g_synaptics_set_vertical_scroll_delta (GSynaptics *synaptics, gint delta)
 }
 
 void
-g_synaptics_set_accel(GSynaptics *synaptics, gdouble delta)
+g_synaptics_set_accel_factor(GSynaptics *synaptics, gint value)
 {
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
 	if (!g_synaptics_is_valid(synaptics))
@@ -709,20 +713,19 @@ g_synaptics_set_accel(GSynaptics *synaptics, gdouble delta)
 	if (priv->synclient)
 	{
 		gchar *command;
-		command = g_strdup_printf ("synclient AccelFactor=%lf",
-			       		   delta);
-		/* TODO check that %lf is  right*/
+		command = g_strdup_printf ("synclient AccelFactor=%f",
+			       		   (gdouble)value / 1000);
 		g_spawn_command_line_async (command, NULL);
 		g_free (command);
 	}
 	else
 	{
-		SYNSHM(synaptics)->accl = delta;
+		SYNSHM(synaptics)->accl = ((double)value) / 1000;
 	}
 }
 
 void
-g_synaptics_set_max_speed(GSynaptics *synaptics, gdouble delta)
+g_synaptics_set_max_speed(GSynaptics *synaptics, gint value)
 {
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
 	if (!g_synaptics_is_valid(synaptics))
@@ -731,20 +734,19 @@ g_synaptics_set_max_speed(GSynaptics *synaptics, gdouble delta)
 	if (priv->synclient)
 	{
 		gchar *command;
-		command = g_strdup_printf ("synclient MaxSpeed=%lf",
-			       		   delta);
-		/* TODO check that %lf is right */
+		command = g_strdup_printf ("synclient MaxSpeed=%f",
+			       		   (gdouble)value / 1000);
 		g_spawn_command_line_async (command, NULL);
 		g_free (command);
 	}
 	else
 	{
-		SYNSHM(synaptics)->max_speed = delta;
+		SYNSHM(synaptics)->max_speed = ((double)value) / 1000;
 	}
 }
 
 void
-g_synaptics_set_min_speed(GSynaptics *synaptics, gdouble delta)
+g_synaptics_set_min_speed(GSynaptics *synaptics, gint value)
 {
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
 	if (!g_synaptics_is_valid(synaptics))
@@ -753,15 +755,14 @@ g_synaptics_set_min_speed(GSynaptics *synaptics, gdouble delta)
 	if (priv->synclient)
 	{
 		gchar *command;
-		command = g_strdup_printf ("synclient MinSpeed=%lf",
-			       		   delta);
-		/* TODO check that %lf is right */
+		command = g_strdup_printf ("synclient MinSpeed=%f",
+			       		   (gdouble)value / 1000);
 		g_spawn_command_line_async (command, NULL);
 		g_free (command);
 	}
 	else
 	{
-		SYNSHM(synaptics)->min_speed = delta;
+		SYNSHM(synaptics)->min_speed = ((double)value) / 1000;
 	}
 }
 
