@@ -22,8 +22,9 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
+#include <stdlib.h>
 
 #include "gsynaptics.h"
 #include "gsynaptics-conf.h"
@@ -56,7 +57,7 @@ setup_user_value (GSynaptics *synaptics)
 	b_value = gconf_client_get_bool (gconf, CIRCULARSCROLLING_KEY, NULL);
 	g_synaptics_set_circular_scroll_delta (synaptics, i_value);
 	g_synaptics_set_circular_scroll_enabled (synaptics, b_value);
-	/* the trigger of curcular scrolling */
+	/* the trigger of circular scrolling */
 	i_value = gconf_client_get_int (gconf, CIRCSCROLLTRIGGER_KEY, NULL);
 	g_synaptics_set_circular_scroll_trigger (synaptics, i_value);
 	
@@ -80,6 +81,19 @@ setup_user_value (GSynaptics *synaptics)
 	/* edge motion */
 	b_value = gconf_client_get_bool (gconf, EDGEMOTIONUSEALWAYS_KEY, NULL);
 	g_synaptics_set_edge_motion_enabled (synaptics, b_value);
+
+	/* min speed */
+	i_value = gconf_client_get_int (gconf, MINSPEED_KEY, NULL);
+	g_synaptics_set_min_speed (synaptics, i_value);
+
+	/* max speed */
+	i_value = gconf_client_get_int (gconf, MAXSPEED_KEY, NULL);
+	g_synaptics_set_max_speed (synaptics, i_value);
+
+	/* accel factor */
+	i_value = gconf_client_get_int (gconf, ACCELFACTOR_KEY, NULL);
+	g_synaptics_set_accel_factor (synaptics, i_value);
+
 }
 
 int
@@ -91,10 +105,7 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("gsynaptics-init", VERSION,
-			LIBGNOMEUI_MODULE, argc, argv,
-			GNOME_PARAM_APP_DATADIR, NULL,
-			NULL);
+	gtk_init (&argc, &argv);
 
 	synaptics = g_synaptics_new ();
 
@@ -102,7 +113,7 @@ main (int argc, char **argv)
 	{
 		g_object_unref (synaptics);
 		g_printerr (_("GSynaptics couldn't initialize.\n"
-			      "You have to set 'SHMConfig' 'true' in Xorg.conf or XFree86.conf to use GSynaptics\n"));
+			      "You have to set 'SHMConfig' 'true' in xorg.conf or XFree86.conf to use GSynaptics\n"));
 		exit(1);
 	}
 
