@@ -22,9 +22,11 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
+#include <string.h>
+#include <stdlib.h>
 
 #include "gsynaptics.h"
 #include "gsynaptics-conf.h"
@@ -480,16 +482,18 @@ cb_cursor_movement_toggled (GtkToggleButton *button, GladeXML *dialog)
 }
 
 static gboolean
-cb_accel_change (GtkRange *range, GtkScrollType scroll,
+cb_accel_factor_change (GtkRange *range, GtkScrollType scroll,
 			     gdouble value, GladeXML *dialog)
 {
 	GSynaptics *synaptics;
 	
 	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
 
-	g_synaptics_set_accel(synaptics, value);
+	g_synaptics_set_accel_factor (synaptics, (gint)value);
+	gconf_client_set_int (gconf, ACCELFACTOR_KEY, (gint)value, NULL);
 
 	return FALSE;
+
 }
 
 static gboolean
@@ -500,7 +504,8 @@ cb_min_speed_change (GtkRange *range, GtkScrollType scroll,
 	
 	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
 
-	g_synaptics_set_min_speed(synaptics, value);
+	g_synaptics_set_min_speed(synaptics, (gint)value);
+	gconf_client_set_int (gconf, MINSPEED_KEY, (gint)value, NULL);
 
 	return FALSE;
 }
@@ -513,7 +518,8 @@ cb_max_speed_change (GtkRange *range, GtkScrollType scroll,
 	
 	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
 
-	g_synaptics_set_max_speed(synaptics, value);
+	g_synaptics_set_max_speed(synaptics, (gint)value);
+	gconf_client_set_int (gconf, MAXSPEED_KEY, (gint)value, NULL);
 
 	return FALSE;
 }
@@ -529,6 +535,7 @@ setup_dialog (GladeXML *dialog)
 	gchar *path;
 	gboolean value;
 	gint num;
+
 	
 	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
 	
@@ -653,26 +660,26 @@ setup_dialog (GladeXML *dialog)
 	g_signal_connect (G_OBJECT (check), "toggled",
 			  G_CALLBACK (cb_cursor_movement_toggled), dialog);
 
+
 	/* fourth pane */
-	scale = WID ("accel_scale");
-	/*num = g_synaptics_accel_delta (synaptics);*/
-	/* TODO figure out what to do with this g_synaptics_*_delta bit
-	 * or if it's even needed... */
-	/*gtk_range_set_value (GTK_RANGE (scale), num * -1);*/
+	scale = WID ("accel_factor_scale");
+	num = g_synaptics_accel_factor (synaptics);
+	gtk_range_set_value (GTK_RANGE (scale), num);
 	g_signal_connect (G_OBJECT (scale), "change-value",
-			  G_CALLBACK (cb_accel_change), dialog);
-			  
+			  G_CALLBACK (cb_accel_factor_change), dialog);
+
 	scale = WID ("min_speed_scale");
-	num = g_synaptics_min_speed_delta (synaptics);
-	gtk_range_set_value (GTK_RANGE (scale), num * -1);
+	num = g_synaptics_min_speed (synaptics);
+	gtk_range_set_value (GTK_RANGE (scale), num);
 	g_signal_connect (G_OBJECT (scale), "change-value",
 			  G_CALLBACK (cb_min_speed_change), dialog);
-			  	
+
 	scale = WID ("max_speed_scale");
-	num = g_synaptics_max_speed_delta (synaptics);
-	gtk_range_set_value (GTK_RANGE (scale), num * -1);
+	num = g_synaptics_max_speed (synaptics);
+	gtk_range_set_value (GTK_RANGE (scale), num);
 	g_signal_connect (G_OBJECT (scale), "change-value",
 			  G_CALLBACK (cb_max_speed_change), dialog);
+
 			  
 	/* dialog window */
 	widget = WID ("gsynaptics_dialog");
@@ -683,7 +690,7 @@ setup_dialog (GladeXML *dialog)
 
 	gtk_window_set_default_size (GTK_WINDOW (widget), 400, -1);
 
-	path = gnome_pixmap_file ("touchpad.png");
+	path = g_build_filename (DATADIR "/pixmaps", "touchpad.png");
 	if (path)
 	{
 		icon_pixbuf = gdk_pixbuf_new_from_file (path, NULL);
@@ -712,10 +719,7 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("gsynaptics", VERSION,
-			LIBGNOMEUI_MODULE, argc, argv,
-			GNOME_PARAM_APP_DATADIR, DATADIR,
-			NULL);
+	gtk_init (&argc, &argv);
 
 	synaptics = g_synaptics_new ();
 	if (!g_synaptics_is_available(synaptics))
